OC.L10N.register(
    "mail",
    {
    "Important mail" : "重要なメール",
    "No message found yet" : "メッセージはまだありません",
    "Set up an account" : "アカウントを設定",
    "Unread mail" : "未読メール",
    "Important" : "重要",
    "Work" : "仕事",
    "Personal" : "個人",
    "To Do" : "To Do",
    "Later" : "後で",
    "Mail" : "メール",
    "Mails" : "メール",
    "💌 A mail app for Nextcloud" : "💌Nextcloudのメールアプリ",
    "Drafts are saved in:" : "下書きの保存先:",
    "Sent messages are saved in:" : "送信済みの保存先:",
    "Deleted messages are moved in:" : "削除されたメッセージの移動先:",
    "Auto" : "自動",
    "Name" : "名前",
    "Mail address" : "メールアドレス",
    "Password" : "パスワード",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAPホスト",
    "IMAP Security" : "IMAPセキュリティ",
    "None" : "なし",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAPポート",
    "IMAP User" : "IMAPユーザー",
    "IMAP Password" : "IMAPパスワード",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTPホスト",
    "SMTP Security" : "SMTPセキュリティ",
    "SMTP Port" : "SMTPポート",
    "SMTP User" : "SMTPユーザー",
    "SMTP Password" : "SMTPパスワード",
    "Connecting" : "接続中",
    "Sign in with Google" : "Googleでサインイン",
    "Save" : "保存",
    "Connect" : "接続",
    "Password required" : "パスワードが必要です",
    "Loading account" : "アカウントを読み込み中",
    "Account settings" : "アカウント設定",
    "Aliases" : "別名",
    "Signature" : "署名",
    "A signature is added to the text of new messages and replies." : "署名は、新しいメッセージと返信の本文に追加されます。",
    "Writing mode" : "書き込みモード",
    "Preferred writing mode for new messages and replies." : "新しいメッセージと返信に使うお好みの書き込みモード",
    "Default folders" : "デフォルトフォルダー",
    "Autoresponder" : "自動返信",
    "Please connect to a sieve server first." : "はじめにsieveサーバーに接続してください。",
    "Mail server" : "メールサーバー",
    "Delete alias" : "別名を削除",
    "Go back" : "戻る",
    "Change name" : "名称変更",
    "Email address" : "メールアドレス",
    "Add alias" : "別名を追加",
    "Create alias" : "別名をつける",
    "Cancel" : "キャンセル",
    "Add mail account" : "メールアカウントを追加",
    "Use Gravatar and favicon avatars" : "Gravatarとfaviconのアバターを使用する",
    "Show keyboard shortcuts" : "キーボード ショートカット",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "操作手順についてのデータ収集をアプリに許可します。このデータに基づき、アプリがあなた好みに適応します。データはローカルにしか保存されません。",
    "Put my text to the bottom of a reply instead of on top of it." : "返信をメール本文の先頭ではなく最後に挿入します。",
    "Could not update preference" : "環境設定を更新できませんでした",
    "Could not update certificate" : "証明書を更新できませんでした",
    "From" : "差出人",
    "Select account" : "アカウントを選択",
    "To" : "宛先",
    "Contact or email address …" : "連絡先もしくはメールアドレス…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "No contacts found." : "連絡先が見つかりません。",
    "Subject" : "件名",
    "Subject …" : "件名...",
    "This message came from a noreply address so your reply will probably not be read." : "このメッセージは送信専用アドレスから送信されたため、返信しても確認されない恐れがあります。",
    "The following recipients do not have a PGP key: {recipients}." : "次の受信者はPGPキーを持っていません: {recipients}",
    "Write message …" : "メッセージを書く…",
    "Saving draft …" : "下書きを保存しています",
    "Draft saved" : "下書きを保存しました。",
    "Upload attachment" : "添付ファイルをアップロードする",
    "Add attachment from Files" : "ファイルから添付ファイルの追加",
    "Enable formatting" : "フォーマットを有効にする",
    "Encrypt message with Mailvelope" : "Mailvelopeでメッセージを暗号化",
    "Enter a date" : "日付を入力してください",
    "Send" : "送信",
    "Message {id} could not be found" : "メッセージ {id} が見つかりません",
    "Choose a file to add as attachment" : "添付として追加するファイルを選択",
    "Choose a file to share as a link" : "共有リンクにして送信するファイルを選択",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個の添付ファイル"],
    "Confirm" : "承認",
    "Plain text" : "プレーンテキスト",
    "Rich text" : "リッチテキスト",
    "No messages in this mailbox" : "このメールボックスにメッセージはありません",
    "No messages" : "メッセージはありません",
    "Draft: " : "下書き",
    "Unfavorite" : "お気に入りから外す",
    "Favorite" : "お気に入り",
    "Unread" : "未読",
    "Read" : "読み込み",
    "Mark not spam" : "迷惑メールとしない",
    "Mark as spam" : "迷惑メールとする",
    "Unselect" : "選択解除",
    "Select" : "選択",
    "Edit tags" : "タグを編集",
    "Delete thread" : "スレッドを削除",
    "More actions" : "その他のアクション",
    "Back" : "戻る",
    "Edit as new message" : "新しいメッセージとして編集",
    "Create event" : "イベントを作成",
    "Create task" : "タスクを作成する",
    "Blind copy recipients only" : "BCC受信者のみ",
    "Could not delete message" : "メッセージを削除できませんでした",
    "Forward" : "転送",
    "Load more" : "さらに読み込む",
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["{number}をスパムとしてマーク"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number}件をスパムでないとマーク"],
    "Report this bug" : "不具合を報告",
    "All day" : "終日",
    "Create" : "作成",
    "Event created" : "イベントが作成しました",
    "Could not create event" : "イベントを作成できませんでした。",
    "Save to" : "に保存",
    "Comment" : "コメント",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "More options" : "追加のオプション",
    "Could not open mailbox" : "メールボックスを開けませんでした",
    "Loading messages …" : "メッセージの読み込み中…",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "メールをインデックスしています。大きいメールボックスの場合はしばらくお待ちください。",
    "Choose" : "選択",
    "Important info" : "重要な情報",
    "Other" : "その他",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "あなたの過去の操作を元にしてメールには自動的に重要マークがつけられます。最初のうちは重要マークを手動でつけたり外したりしてシステムに重要なメールを教える必要がありますが、精度は徐々に向上します。",
    "The sender of this message has asked to be notified when you read this message." : "メッセージの送信者はあなたがこのメッセージを開封した通知を求めています。",
    "You sent a read confirmation to the sender of this message." : "メッセージの開封通知をメッセージの送信者へ送信しました。",
    "Reply" : "返信",
    "Reply to sender only" : "送信者のみに返信",
    "Move message" : "メッセージを移動",
    "View source" : "ソースを表示",
    "Import into calendar" : "カレンダーにインポート",
    "Download attachment" : "添付ファイルをダウンロード",
    "Save to Files" : "ファイルに保存",
    "Unnamed" : "名称未設定",
    "Embedded message" : "埋込メッセージ",
    "Choose a folder to store the attachment in" : "添付ファイルを保存するフォルダーを選択",
    "Save all to Files" : "すべてファイルに保存",
    "Download Zip" : "ZIPファイルをダウンロード",
    "Choose a folder to store the attachments in" : "添付ファイルを保存するフォルダーを選択してください",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "PGPで本文が暗号化されています。復号化するためにMailvelopeをインストールしてください。",
    "The images have been blocked to protect your privacy." : "画像はあなたのプライバシーを守るためにブロックされています。",
    "Show images" : "画像を表示する",
    "Show images temporarily" : "画像を一時的に表示",
    "Move" : "移動",
    "Moving" : "移動中",
    "Quota" : "クオータ",
    "Show only subscribed mailboxes" : "購読したメールボックスのみ表示",
    "Add mailbox" : "メールボックスを追加",
    "Saving" : "保存しています",
    "Move up" : "上に移動",
    "Move down" : "下に移動",
    "Remove account" : "アカウント削除",
    "Loading …" : "読み込み中...",
    "Not supported by the server" : "サーバーに対応していません",
    "{usage} of {limit} used" : "{usage} / {limit} 使われています",
    "Remove account {email}" : "アカウント {email} の削除",
    "Remove {email}" : "{email} を削除",
    "Show all subscribed mailboxes" : "購読したメールボックスを全て表示",
    "Show all mailboxes" : "全てのメールボックスを表示",
    "Collapse mailboxes" : "メールボックスを非表示",
    "Mark all as read" : "すべて既読にする",
    "Mark all messages of this mailbox as read" : "このフォルダのすべてのメッセージを開封済みにする",
    "Add submailbox" : "サブメールボックスを追加",
    "Edit name" : "名前を編集",
    "Clear cache" : "キャッシュをクリア",
    "Clear locally cached data, in case there are issues with synchronization." : "同期の問題を解消を解消するために、ローカルにキャッシュされたデータを消去",
    "Subscribed" : "購読",
    "Sync in background" : "バックグラウンドで同期",
    "Delete mailbox" : "メールボックスを削除",
    "All messages in mailbox will be deleted." : "メールボックスにある全てのメッセージが削除されます。",
    "The mailbox and all messages in it will be deleted." : "メールボックスと中にある全てのメッセージが削除されます。",
    "Delete mailbox {name}" : "メールボックス「{name}」を削除",
    "An error occurred, unable to rename the mailbox." : "エラー:メールボックスの名前を変更できませんでした。",
    "_{total} message_::_{total} messages_" : ["{total} メッセージ"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} メッセージの内 {unread} 件が未開封"],
    "Outbox" : "送信トレイ",
    "New message" : "新規メッセージ",
    "Refresh" : "同期",
    "Error sending your message" : "メッセージ送信エラー",
    "Retry" : "再試行",
    "Uploading attachments …" : "添付ファイルをアップロード",
    "Sending …" : "送信中 …",
    "First day" : "初日",
    "Message" : "メッセージ",
    "Oh Snap!" : "おっと！",
    "Could not open outbox" : "送信トレイを開けませんでした",
    "Delete" : "削除",
    "Message could not be sent" : "メッセージを送信できませんでした",
    "Message deleted" : "メッセージを削除しました",
    "Add to Contact" : "連絡先に追加",
    "New Contact" : "新しい連絡先",
    "Copy to clipboard" : "クリップボードにコピー",
    "Contact name …" : "連絡先の名前…",
    "Add" : "追加",
    "Close" : "閉じる",
    "Body" : "本文",
    "Tags" : "タグ",
    "Select tags" : "タグを選択",
    "Clear" : "クリア",
    "Search" : "検索",
    "Date" : "日付",
    "Disabled" : "無効",
    "Enabled" : "有効",
    "Sieve Host" : "Sieveホスト",
    "Sieve Port" : "Sieveポート",
    "Custom" : "カスタム",
    "Sieve User" : "Sieveユーザー",
    "Signature …" : "署名…",
    "Save signature" : "署名を保存",
    "Delete tag" : "タグを削除",
    "An error occurred, unable to rename the tag." : "エラー:タグの名前を変更できませんでした",
    "Add tag" : "タグを追加",
    "Tag already exists" : "タグはすでに存在します",
    "An error occurred, unable to create the tag." : "エラー:タグを作成できませんでした",
    "Not found" : "見つかりませんでした",
    "Could not load your message thread" : "メッセージを読み込めませんでした",
    "Unsubscribe" : "購読解除",
    "Mark as unread" : "未読にする",
    "Mark as read" : "既読にする",
    "Delete message" : "メッセージを削除",
    "Message source" : "メッセージソース",
    "This message was encrypted by the sender before it was sent." : "このメッセージは送信前に送信者よって暗号化されました。",
    "Remove" : "削除",
    "domain" : "ドメイン",
    "(organizer)" : "（主催者）",
    "Untitled event" : "無題のイベント",
    "Import into {calendar}" : "{calendar} へインポート",
    "Event imported into {calendar}" : "イベントが {calendar} にインポートされました",
    "Airplane" : "飛行機",
    "Reservation {id}" : "予約ID {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{depAirport} から {arrAirport} 行きのフライト番号 {flightNr}",
    "Train" : "列車",
    "{trainNr} from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車番号 {trainNr}",
    "Train from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車",
    "Mail app" : "メールアプリ",
    "The mail app allows users to read mails on their IMAP accounts." : "メールアプリで、ユーザーはIMAPアカウントでメールを読むことができます。",
    "Add new config" : "新しい設定を追加",
    "Anti Spam" : "アンチスパム",
    "The original message will be attached as a \"message/rfc822\" attachment." : "元のメッセージは \"message/rfc822\" の形式で添付されます。",
    "Reset" : "リセット",
    "Client ID" : "クライアント ID",
    "Client secret" : "クライアントシークレット",
    "Email: {email}" : "メール: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {host}:{port}の{user} ({ssl} 暗号化)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {host}:{port}の{user} ({ssl} 暗号化)",
    "General" : "一般",
    "IMAP" : "IMAP",
    "User" : "ユーザー",
    "Host" : "ホスト",
    "Port" : "ポート",
    "SMTP" : "SMTP",
    "Save Config" : "設定を保存",
    "With the settings above, the app will create account settings in the following way:" : "上記の設定では、アプリは次の方法でアカウント設定を作成します：",
    "E-mail address" : "メールアドレス",
    "Valid until" : "有効期限",
    "Certificate" : "証明",
    "Submit" : "送信",
    "Keyboard shortcut" : "キーボードショートカット",
    "Keyboard shortcuts" : "キーボード ショートカット",
    "Speed up your Mail experience with these quick shortcuts." : "ショートカットであなたのメール操作をスピードアップしてください。",
    "Compose new message" : "新しいメッセージを作成する",
    "Newer message" : "新しいメッセージ",
    "Older message" : "古いメッセージ",
    "Toggle star" : "スターを切り替え",
    "Toggle unread" : "未読を切り替え",
    "Archive" : "アーカイブ",
    "Account connected" : "アカウント接続済",
    "Connect your mail account" : "あなたのメールアカウントに接続",
    "Itinerary for {type} is not supported yet" : "{type} タイプの旅程はまだサポートされていません",
    "All" : "すべて",
    "Drafts" : "下書き",
    "Favorites" : "お気に入り",
    "Priority inbox" : "優先受信箱",
    "All inboxes" : "すべての受信トレイ",
    "Inbox" : "受信箱",
    "Junk" : "迷惑メール",
    "Sent" : "送信済み",
    "Trash" : "ゴミ箱",
    "Error while sharing file" : "共有中にエラーが発生しました",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n個の新しいメッセージ\nfrom{from}"],
    "Nextcloud Mail" : "Nextcloud メール",
    "Message sent" : "メッセージ送信済",
    "Could not load {tag}{name}{endtag}" : "{tag} {name} {endtag}を読み込めませんでした",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} の読み込み中に問題が発生しました",
    "Could not load your message" : "あなたのメッセージを読み込めませんでした",
    "Could not load the desired message" : "目的のメッセージを読み込めませんでした",
    "Could not load the message" : "メッセージを読み込めませんでした",
    "Error loading message" : "メッセージ読み込みエラー",
    "Forwarding to %s" : "%s への転送",
    "Click here if you are not automatically redirected within the next few seconds." : "数秒以内に自動的にリダイレクトされない場合は、ここをクリックしてください。",
    "Redirect" : "リダイレクト",
    "The link leads to %s" : "リンクが %s につながります",
    "Continue to %s" : "%s にリダイレクトする"
},
"nplurals=1; plural=0;");
